@@ -401,6 +401,7 @@ cb_change_current_page (GtkNotebook *nb, gint num, gpointer data)
                 cb_timeout, app);
 
         update_sensitivity(app);
+        gtk_widget_grab_focus(app->tree);
     }
     else {
         if (app->timeout) {
@@ -475,6 +476,20 @@ cb_timeout (gpointer data)
     return TRUE;
 }
 
+void
+cb_refresh_icons (GtkIconTheme *theme, gpointer data)
+{
+    ProcmanApp * const app = static_cast<ProcmanApp *>(data);
+    if(app->timeout) {
+        g_source_remove (app->timeout);
+    }
+
+    for (ProcInfo::Iterator it(ProcInfo::begin()); it != ProcInfo::end(); ++it) {
+        app->pretty_table->set_icon(*(it->second));
+    }
+
+    cb_timeout(app);
+}
 
 void
 cb_radio_processes(GtkAction *action, GtkRadioAction *current, gpointer data)
