@@ -103,7 +103,7 @@ format_memsize(guint64 size)
     if (size == 0)
         return g_strdup(_("N/A"));
     else
-        return procman::format_size(size);
+        return g_format_size_full(size, G_FORMAT_SIZE_IEC_UNITS);
 }
 
 static void
@@ -123,7 +123,7 @@ fill_proc_properties (GtkWidget *tree, ProcInfo *info)
     if (sysctl (mib, G_N_ELEMENTS (mib), &cinf, &size, NULL, 0) == -1)
         HZ = 100;
     else
-        HZ = cinf.hz;
+        HZ = (cinf.stathz ? cinf.stathz : cinf.hz);
 #endif
     proc_arg proc_props[] = {
         { N_("Process Name"), g_strdup_printf("%s", info->name)},
