@@ -11,7 +11,7 @@
 #include <algorithm>
 
 #include "smooth_refresh.h"
-#include "procman.h"
+#include "procman-app.h"
 #include "util.h"
 
 
@@ -83,7 +83,7 @@ void SmoothRefresh::reset()
     glibtop_get_cpu(&cpu);
     glibtop_get_proc_time(&proctime, getpid());
 
-    this->interval = ProcData::get_instance()->config.update_interval;
+    this->interval = ProcmanApp::get()->config.update_interval;
     this->last_pcpu = PCPU_LO;
     this->last_total_time = cpu.total;
     this->last_cpu_time = proctime.rtime;
@@ -102,7 +102,7 @@ SmoothRefresh::~SmoothRefresh()
 bool
 SmoothRefresh::get(guint &new_interval)
 {
-    const unsigned config_interval = ProcData::get_instance()->config.update_interval;
+    const unsigned config_interval = ProcmanApp::get()->config.update_interval;
 
     g_assert(this->interval >= config_interval);
 
