@@ -395,7 +395,7 @@ namespace procman
 
         g_value_unset(&value);
 
-        char *str = procman::format_size(size);
+        char *str = g_format_size_full(size, G_FORMAT_SIZE_IEC_UNITS);
         g_object_set(renderer, "text", str, NULL);
         g_free(str);
     }
@@ -436,13 +436,46 @@ namespace procman
             g_free(str);
         }
         else {
-            char *str = procman::format_size(size);
+            char *str = g_format_size_full(size, G_FORMAT_SIZE_IEC_UNITS);
             g_object_set(renderer, "text", str, NULL);
             g_free(str);
         }
 
     }
+    
+    /*
+        Cell data function to format a size value with SI units (to be used only for disk size, see bugzilla 693630)
+    */
+    void size_si_cell_data_func(GtkTreeViewColumn *, GtkCellRenderer *renderer,
+                             GtkTreeModel *model, GtkTreeIter *iter,
+                             gpointer user_data)
+    {
+        const guint index = GPOINTER_TO_UINT(user_data);
 
+        guint64 size;
+        GValue value = { 0 };
+
+        gtk_tree_model_get_value(model, iter, index, &value);
+
+        switch (G_VALUE_TYPE(&value)) {
+            case G_TYPE_ULONG:
+                size = g_value_get_ulong(&value);
+                break;
+
+            case G_TYPE_UINT64:
+                size = g_value_get_uint64(&value);
+                break;
+
+            default:
+                g_assert_not_reached();
+        }
+
+        g_value_unset(&value);
+
+        char *str = g_format_size(size);
+        g_object_set(renderer, "text", str, NULL);
+        g_free(str);
+    }
 
     void duration_cell_data_func(GtkTreeViewColumn *, GtkCellRenderer *renderer,
                                  GtkTreeModel *model, GtkTreeIter *iter,
